ls.joyous
===============

.. image:: https://secure.travis-ci.org/linuxsoftware/ls.joyous.svg?branch=master
   :target: https://travis-ci.org/linuxsoftware/ls.joyous
.. image:: https://coveralls.io/repos/github/linuxsoftware/ls.joyous/badge.svg?branch=master
   :target: https://coveralls.io/github/linuxsoftware/ls.joyous?branch=master

About
------
Joyous is a reusable calendar application for Wagtail. Features include rrule
based recurring events with cancellations and postponements; iCal import and export; Gcal export; RSS feed; event permissioning; timezone handling; and multi-site aware calendars.

Documentation
-------------
The documentation for using and developing with Joyous can be found at 
https://joyous.readthedocs.io.

Demo
----
Yet another demonstration Wagtail website `code <http://github.com/linuxsoftware/orange-wagtail-site>`_ | `live <http://demo.linuxsoftware.nz>`_

Getting Help
-------------
Please report bugs or ask questions using the `Issue Tracker <http://github.com/linuxsoftware/ls.joyous/issues>`_.

Languages
---------
Joyous has been translated into French, German and Brazilian-Portuguese.
Translations into other languages would be welcome.

Thanks To
---------

Contributors
~~~~~~~~~~~~
Thanks to everyone who has `contributed <https://github.com/linuxsoftware/ls.joyous/graphs/contributors>`_ to Joyous.

Tools
~~~~~
`Sauce Labs <https://saucelabs.com>`_ for their cross-browser testing platform.

.. image:: /docs/powered-by-sauce-labs.png

